@@ -33,9 +33,10 @@
 #  define KXMLRPCCLIENT_DEPRECATED_NO_EXPORT KXMLRPCCLIENT_NO_EXPORT KXMLRPCCLIENT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KXMLRPCCLIENT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KXMLRPCCLIENT_NO_DEPRECATED
+#    define KXMLRPCCLIENT_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* KXMLRPCCLIENT_EXPORT_H */
